@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
@@ -21,30 +21,30 @@ else:
 
 __all__ = (
     "AlarmExistsWaiterName",
-    "AlarmType",
-    "AnomalyDetectorStateValue",
-    "ComparisonOperator",
+    "AlarmTypeType",
+    "AnomalyDetectorStateValueType",
+    "ComparisonOperatorType",
     "CompositeAlarmExistsWaiterName",
     "DescribeAlarmHistoryPaginatorName",
     "DescribeAlarmsPaginatorName",
     "GetMetricDataPaginatorName",
-    "HistoryItemType",
+    "HistoryItemTypeType",
     "ListDashboardsPaginatorName",
     "ListMetricsPaginatorName",
-    "MetricStreamOutputFormat",
-    "RecentlyActive",
-    "ScanBy",
-    "StandardUnit",
-    "StateValue",
-    "Statistic",
-    "StatusCode",
+    "MetricStreamOutputFormatType",
+    "RecentlyActiveType",
+    "ScanByType",
+    "StandardUnitType",
+    "StateValueType",
+    "StatisticType",
+    "StatusCodeType",
 )
 
 
 AlarmExistsWaiterName = Literal["alarm_exists"]
-AlarmType = Literal["CompositeAlarm", "MetricAlarm"]
-AnomalyDetectorStateValue = Literal["PENDING_TRAINING", "TRAINED", "TRAINED_INSUFFICIENT_DATA"]
-ComparisonOperator = Literal[
+AlarmTypeType = Literal["CompositeAlarm", "MetricAlarm"]
+AnomalyDetectorStateValueType = Literal["PENDING_TRAINING", "TRAINED", "TRAINED_INSUFFICIENT_DATA"]
+ComparisonOperatorType = Literal[
     "GreaterThanOrEqualToThreshold",
     "GreaterThanThreshold",
     "GreaterThanUpperThreshold",
@@ -57,13 +57,13 @@ CompositeAlarmExistsWaiterName = Literal["composite_alarm_exists"]
 DescribeAlarmHistoryPaginatorName = Literal["describe_alarm_history"]
 DescribeAlarmsPaginatorName = Literal["describe_alarms"]
 GetMetricDataPaginatorName = Literal["get_metric_data"]
-HistoryItemType = Literal["Action", "ConfigurationUpdate", "StateUpdate"]
+HistoryItemTypeType = Literal["Action", "ConfigurationUpdate", "StateUpdate"]
 ListDashboardsPaginatorName = Literal["list_dashboards"]
 ListMetricsPaginatorName = Literal["list_metrics"]
-MetricStreamOutputFormat = Literal["json", "opentelemetry0.7"]
-RecentlyActive = Literal["PT3H"]
-ScanBy = Literal["TimestampAscending", "TimestampDescending"]
-StandardUnit = Literal[
+MetricStreamOutputFormatType = Literal["json", "opentelemetry0.7"]
+RecentlyActiveType = Literal["PT3H"]
+ScanByType = Literal["TimestampAscending", "TimestampDescending"]
+StandardUnitType = Literal[
     "Bits",
     "Bits/Second",
     "Bytes",
@@ -92,6 +92,6 @@ StandardUnit = Literal[
     "Terabytes",
     "Terabytes/Second",
 ]
-StateValue = Literal["ALARM", "INSUFFICIENT_DATA", "OK"]
-Statistic = Literal["Average", "Maximum", "Minimum", "SampleCount", "Sum"]
-StatusCode = Literal["Complete", "InternalError", "PartialData"]
+StateValueType = Literal["ALARM", "INSUFFICIENT_DATA", "OK"]
+StatisticType = Literal["Average", "Maximum", "Minimum", "SampleCount", "Sum"]
+StatusCodeType = Literal["Complete", "InternalError", "PartialData"]
