@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html)
+[Open documentation](./waiters.md)
 
 Usage::
 
@@ -24,55 +24,55 @@ from typing import List
 
 from botocore.waiter import Waiter as Boto3Waiter
 
-from mypy_boto3_cloudwatch.literals import AlarmType, StateValue
-from mypy_boto3_cloudwatch.type_defs import WaiterConfigTypeDef
+from .literals import AlarmTypeType, StateValueType
+from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 
 class AlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/cloudwatch.html#CloudWatch.Waiter.alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/cloudwatch.html#CloudWatch.Waiter.alarm_exists)[Show boto3-stubs documentation](./waiters.md#alarmexistswaiter)
     """
 
     def wait(
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmType] = None,
+        AlarmTypes: List[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
-        StateValue: StateValue = None,
+        StateValue: StateValueType = None,
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExistsWaiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExistsWaiter)
+        [Show boto3-stubs documentation](./waiters.md#alarmexists)
         """
 
 
 class CompositeAlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/cloudwatch.html#CloudWatch.Waiter.composite_alarm_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/cloudwatch.html#CloudWatch.Waiter.composite_alarm_exists)[Show boto3-stubs documentation](./waiters.md#compositealarmexistswaiter)
     """
 
     def wait(
         self,
         AlarmNames: List[str] = None,
         AlarmNamePrefix: str = None,
-        AlarmTypes: List[AlarmType] = None,
+        AlarmTypes: List[AlarmTypeType] = None,
         ChildrenOfAlarmName: str = None,
         ParentsOfAlarmName: str = None,
-        StateValue: StateValue = None,
+        StateValue: StateValueType = None,
         ActionPrefix: str = None,
         MaxRecords: int = None,
         NextToken: str = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExistsWaiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExistsWaiter)
+        [Show boto3-stubs documentation](./waiters.md#compositealarmexists)
         """
